class WaterMeter:
    """Represents the water meter."""

    def __init__(self, volume: int, duration: int) -> None:
        """Create an Water Meter object."""

        self.volume = volume
        self.duration = duration